#!/usr/bin/env python

import requests
import time


class Client(object):

    def __init__(self, url, user_id, user_secret) -> None:
        """
        The Client object is used to wrap http request and token handling in a simple object.

        :param url: tronity api address
        :type url:str
        :param user_id: tronity user id
        :type user_id:str
        :param user_secret: tronity user secret
        :type user_secret:str
        """

        self.url = url
        self.user_id = user_id
        self.user_secret = user_secret
        self._jwt = self._get_jwt()
        self._session_handling()
        self.session = self._session_handling

    def _session_handling(self) -> requests.Session:
        """
        Function to deal with expired jwt tokens.

        :return session: requests session with authorization data
        :rtype session:Session
        """

        if (self._jwt["expires_in"] / 1000) < int(time.time()) or self._jwt is None:
            self._jwt = self._get_jwt()

        session = requests.Session()
        session.headers.update({"Authorization": self._jwt["access_token"]})

        return session

    def _get_jwt(self) -> dict:
        """
        Function to get actual jwt token from tonity api.

        :return jwt: dictionary with token, expiration and token type
        :rtype jwt:dict
        """
        payload = {
            "client_id": self.user_id,
            "client_secret": self.user_secret,
            "strategy": "app",
        }
        jwt = requests.post(f"{self.url}/authentication", data=payload).json()

        return jwt
